Этот коммит содержится в:
Jatin Chaudhary
2025-11-10 18:22:03 +00:00
коммит произвёл GitHub
родитель f39a60ac25
Коммит 68098c4d90
-28
Просмотреть файл
@@ -62,34 +62,6 @@ TEST_CASE("Unit_hipIpcGetMemHandle_Positive_Unique_Handles_Separate_Allocations"
HIP_CHECK(hipFree(ptr2));
}
/**
* Test Description
* ------------------------
* - Check that unique handles are returned for the same address,
* but separate allocations.
* Test source
* ------------------------
* - unit/device/hipIpcGetMemHandle.cc
* Test requirements
* ------------------------
* - Host specific (LINUX)
* - HIP_VERSION >= 5.2
*/
TEST_CASE("Unit_hipIpcGetMemHandle_Positive_Unique_Handles_Reused_Memory") {
void *ptr1 = nullptr, *ptr2 = nullptr;
hipIpcMemHandle_t handle1, handle2;
HIP_CHECK(hipMalloc(&ptr1, 1024));
HIP_CHECK(hipIpcGetMemHandle(&handle1, ptr1));
HIP_CHECK(hipFree(ptr1));
HIP_CHECK(hipMalloc(&ptr2, 1024));
HIP_CHECK(hipIpcGetMemHandle(&handle2, ptr2));
if (ptr1 == ptr2) CHECK(memcmp(&handle1, &handle2, sizeof(handle1)) != 0);
HIP_CHECK(hipFree(ptr2));
}
/**
* Test Description
* ------------------------